@@ -13,6 +13,24 @@ POSITION_MAP = {
     11: 'UT',
     12: 'BE',
     13: 'IR',
+    14: '',
+    15: 'Rookie',
+    # reverse
+    'PG': 0,
+    'SG': 1,
+    'SF': 2,
+    'PF': 3,
+    'C': 4,
+    'G': 5,
+    'F': 6,
+    'SG/SF': 7,
+    'G/F': 8,
+    'PF/C': 9,
+    'F/C': 10,
+    'UT': 11,
+    'BE': 12,
+    'IR': 13,
+    'Rookie': 15
 }
 
 PRO_TEAM_MAP = {
@@ -91,16 +109,12 @@ STATS_MAP = {
     '38': '',
     '39': '',
     '40': 'MIN',
-    '41': 'GP',
-    '42': '',
+    '41': 'GS',
+    '42': 'GP',
     '43': '',
     '44': '',
     '45': '',
     }
-    
-
-#ACTIVITY_MAP = {
-#}
 
 ACTIVITY_MAP = {
     178: 'FA ADDED',
@@ -113,4 +127,3 @@ ACTIVITY_MAP = {
     'WAIVER': 180,
     'TRADED': 244
 }
-
